Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(635)

Unified Diff: chrome/browser/prefs/pref_service_syncable_util.h

Issue 2459823002: [Sync] Rename syncable_prefs to sync_preferences. (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/prefs/pref_metrics_service.cc ('k') | chrome/browser/prefs/pref_service_syncable_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/prefs/pref_service_syncable_util.h
diff --git a/chrome/browser/prefs/pref_service_syncable_util.h b/chrome/browser/prefs/pref_service_syncable_util.h
index a27a4ca29a1f0437af2b3af3371460125604e0a7..d4149d914d6bd02a0538b404001a686d7beadf1f 100644
--- a/chrome/browser/prefs/pref_service_syncable_util.h
+++ b/chrome/browser/prefs/pref_service_syncable_util.h
@@ -8,30 +8,30 @@
class PrefStore;
class Profile;
-namespace syncable_prefs {
+namespace sync_preferences {
class PrefServiceSyncable;
}
// syncable_prefs::PrefServiceSyncable is a PrefService with added integration
// for sync, and knowledge of how to create an incognito PrefService. For code
// that does not need to know about the sync integration, you should use only
// the plain PrefService type.
//
// For this reason, Profile does not expose an accessor for the
-// syncable_prefs::PrefServiceSyncable type. Instead, you can use the utilities
-// below to retrieve the syncable_prefs::PrefServiceSyncable (or its incognito
-// version) from a Profile.
-syncable_prefs::PrefServiceSyncable* PrefServiceSyncableFromProfile(
+// sync_preferences::PrefServiceSyncable type. Instead, you can use the
+// utilities below to retrieve the sync_preferences::PrefServiceSyncable (or its
+// incognito version) from a Profile.
+sync_preferences::PrefServiceSyncable* PrefServiceSyncableFromProfile(
Profile* profile);
-syncable_prefs::PrefServiceSyncable* PrefServiceSyncableIncognitoFromProfile(
+sync_preferences::PrefServiceSyncable* PrefServiceSyncableIncognitoFromProfile(
Profile* profile);
// Creates an incognito copy of |pref_service| that shares most prefs but uses
// a fresh non-persistent overlay for the user pref store and an individual
// extension pref store (to cache the effective extension prefs for incognito
// windows).
-syncable_prefs::PrefServiceSyncable* CreateIncognitoPrefServiceSyncable(
- syncable_prefs::PrefServiceSyncable* pref_service,
+sync_preferences::PrefServiceSyncable* CreateIncognitoPrefServiceSyncable(
+ sync_preferences::PrefServiceSyncable* pref_service,
PrefStore* incognito_extension_pref_store);
#endif // CHROME_BROWSER_PREFS_PREF_SERVICE_SYNCABLE_UTIL_H_
« no previous file with comments | « chrome/browser/prefs/pref_metrics_service.cc ('k') | chrome/browser/prefs/pref_service_syncable_util.cc » ('j') | no next file with comments »
@@ -8,30 +8,30 @@
class PrefServiceSyncable;
}
-// syncable_prefs::PrefServiceSyncable is a PrefService with added integration
+// sync_preferences::PrefServiceSyncable is a PrefService with added integration
// for sync, and knowledge of how to create an incognito PrefService. For code
// that does not need to know about the sync integration, you should use only

Powered by Google App Engine
This is Rietveld 408576698